@@ -37,11 +37,10 @@
 
 #include "config.h"
 
-ThemeConfig::ThemeConfig(QWidget *parent) :
-    QWidget(parent)
+ThemeConfig::ThemeConfig(const KSharedConfigPtr &config, QWidget *parent) :
+    QWidget(parent),
+    mConfig(config)
 {
-    mConfig = KSharedConfig::openConfig(SDDM_CONFIG_FILE, KConfig::SimpleConfig);
-    
     configUi = new Ui::ThemeConfig();
     configUi->setupUi(this);
     configUi->messageWidget->setVisible(false);
@@ -166,7 +165,9 @@ void ThemeConfig::prepareConfigurationUi(const QString &configPath)
     QFile configFile(configPath);
     
     if (configFile.exists()) {
-        KSharedConfigPtr themeConfig = KSharedConfig::openConfig(configFile.fileName() + ".user", KConfig::SimpleConfig);
+        KSharedConfigPtr themeConfig = KSharedConfig::openConfig(configFile.fileName() + ".user", KConfig::CascadeConfig);
+        themeConfig->addConfigSources({configFile.fileName()});
+
         configUi->customizeBox->setVisible(true);
         configUi->selectBackgroundButton->setImagePath(themeConfig->group("General").readEntry("background"));
     } else {
